@ECHO OFF

REM FreeDOS 1.2+ Basic Networking Support Package.
REM Based on Rugxulo's MetaDOS CONNECT.BAT
REM Released Under GPL v2.0 License.
REM Copyright (c) 2021 Jerome Shidel.

set _LANG.FDNET=%NLSPATH%\FDNET.%LANG%
if not exist %_LANG.FDNET% set _LANG.FDNET=%NLSPATH%\FDNET.EN
if not exist %_LANG.FDNET% set _LANG.FDNET=%DOSDIR%\BIN\FDNET.BAT
if "%1" == "/?" goto ShowHelp
if /I "%1" == "/H" goto ShowHelp
if /I "%1" == "HELP" goto ShowHelp
goto Prepare

:ShowHelp
if not exist %HELPPATH%\FDNET.%LANG% goto ShowHelpEn
type %HELPPATH%\FDNET.%LANG%
goto End

:ShowHelpEn
if not exist %HELPPATH%\FDNET.EN goto ShowHelpless
%HELPPATH%\FDNET.%LANG%
goto End

:ShowHelpless
vecho /g /t %_LANG.FDNET% NO.HELP
goto End

rem Built-in English Translations
INTRO=
ERROR.HARDWARE=/fLightRed Physical hardware networking is not supported at this time. /fGrey /p
ERROR.DOSBOX=/fLightRed DOSBox networking is not supported at this time. /fGrey /p
FOUND.QEMU=/fLightGreen QEMU network detected. /fGrey /p
FOUND.VIRTUALBOX=/fLightGreen VirtualBOX network detected. /fGrey /p
NOTES.VIRTUALBOX=/p /fLightGreen Please note that you may need to adjust your VirtualBOX network settings. /fGrey /p
FOUND.VMWARE=/fLightGreen VMware network detected. /fGrey /p
NOTES.VMWARE=/p /fLightGreen Please note you may need to configure VMware for /fYellow Bridged /fLightGreen mode. /fGrey /p
NO.NETWORK=/fLightRed 'Network is unreachable/unavailable.' /fGray
USER.FDNETPD=/fLightGreen Using custom packet driver settings in /fWhite FDNETPD.BAT /fGrey /p
USER.DRIVER=/fLightGreen Using custom packet driver /fWhite %1 /fGrey /p
NO.HELP=Unable to locate help files.

:Prepare
set _EXIT.FDNET=1
cd \

REM Set configuration environment variables.
if "%MTCPCFG%" == "" SET MTCPCFG=%dosdir%\MTCP.CFG
if "%WATTCP.CFG%" == "" SET WATTCP.CFG=%dosdir%
if "%EMAIL%" == "" SET EMAIL=anonymous@freedos.org

REM Install default configuration files.
if exist %MTCPCFG% goto HasMTCP
copy %DOSDIR%\NETWORK\MTCP.CFG %MTCPCFG%>NUL
:HasMTCP
if exist %WATTCP.CFG%\WATTCP.CFG goto HasWATTCP
copy %DOSDIR%\NETWORK\WATTCP.CFG %WATTCP.CFG%\WATTCP.CFG>NUL
:HasWATTCP

cd %DOSDIR%\NETWORK

if "%1" == "" goto Start
goto %1
goto End

:Start
vecho /g /t %_LANG.FDNET% INTRO

REM Custom User Driver Overrides
if exist FDNETPD.BAT goto FDNETPD
if exist 3C5X9PD.COM goto 3C5X9PD
if exist 3C90XPD.COM goto 3C90XPD

REM Detect Virtual Machine Platform
vinfo /m
if errorlevel 200 goto vmGeneric
if errorlevel 104 goto vmVMware
if errorlevel 103 goto vmVirtualBox
if errorlevel 102 goto vmQEMU
if errorlevel 101 goto vmDOSBox

REM Detect Supported Hardware CPU Level
if errorlevel 6 goto hw686
if errorlevel 5 goto hw586
if errorlevel 4 goto hw486
if errorlevel 3 goto hw386
if errorlevel 2 goto hw286
if errorlevel 1 goto hw186
goto hw086

:hw086
:hw186
:hw286
:hw386
:hw486
:hw586
:hw686
vecho /g /t %_LANG.FDNET% ERROR.HARDWARE
goto End

:vmDOSBox
vecho /g /t %_LANG.FDNET% ERROR.DOSBOX
goto End

:vmQEMU
vecho /g /t %_LANG.FDNET% FOUND.QEMU
goto vmGeneric

:vmVirtualBox
vecho /g /t %_LANG.FDNET% FOUND.VIRTUALBOX
SET _NOTES.FDNET=NOTES.VIRTUALBOX
goto vmGeneric

:vmVMware
vecho /g /t %_LANG.FDNET% FOUND.VMWARE
SET _NOTES.FDNET=NOTES.VMWARE
goto vmGeneric

:FDNETPD
vecho /g /t %_LANG.FDNET% USER.FDNETPD
call FDNETPD.BAT
if errorlevel 1 goto End
goto DHCP

:3C5X9PD
vecho /g /t %_LANG.FDNET% USER.DRIVER 3C5X9PD.COM
LH 3C5X9PD.COM -w 0x60
if errorlevel 1 goto End
goto DHCP

:3C90XPD
vecho /g /t %_LANG.FDNET% USER.DRIVER 3C90XPD.COM
LH 3C90XPD.COM
if errorlevel 1 goto End
goto DHCP

:vmGeneric
REM ---------------------------------------------------------------------------
REM Cut and Paste from CONNECT.BAT
REM ---------------------------------------------------------------------------

berndpci 10222000
if errorlevel 1 goto pcntpk
berndpci 10ec8139
if errorlevel 1 goto rtspkt

goto qemu13

REM ... tested under Windows 7 64-bit Home Premium (no VT-X) ...
REM ... tested successfully with VirtualBox 4.3.6 ...
REM ... (also) qemu -net nic,model=pcnet -net user ...
:amdpd
:pcnet
:pcntpk
pcntpk.com int=0x60
goto finish

REM ... tested natively on Pentium 4 (Dell Dimension) ...
REM ... (sigh) no sources found, so not included here ...
:realtek
:rtl8139
:rtspkt
rtspkt.com 0x60
goto finish

REM ... tested successfully with QEMU 0.9.0 ...
REM qemu -L . -fda /rugxulo/tmp/metados.img -boot a \
REM   -net nic,model=ne2k_isa -net user
REM
:qemu090
:qemu09
:qemu90
:qemu9
ne2000.com -u
ne2000.com 0x60
goto finish

REM ... tested successfully with QEMU 0.13.0 ...
REM qemu -L bios -fda /rugxulo/tmp/metados.img -boot a \
REM   -netdev user,id=usernet -device ne2k_isa,irq=5,netdev=usernet
REM
:qemu0130
:qemu013
:qemu130
:qemu13
ne2000.com -u
ne2000.com 0x60 0x5 0x300
goto finish

:finish
REM ---------------------------------------------------------------------------
REM End of Cut and Paste
REM ---------------------------------------------------------------------------

:DHCP
set _EXIT.FDNET=0
DHCP.EXE
if errorlevel 1 set _EXIT.FDNET=1

if "%_NOTES.FDNET%" == "" goto End
vecho /g /t %_LANG.FDNET% %_NOTES.FDNET%

:End
cd \
if %_EXIT.FDNET% == 1 vecho /g /t %_LANG.FDNET% NO.NETWORK
verrlvl %_EXIT.FDNET%
SET _NOTES.FDNET=
set _EXIT.FDNET=
set _LANG.FDNET=